Denne artikkelen forklarer hvor konfigurasjonen av Delivery Checkout når den brukes med nShift Ship, skiller seg fra standardkonfigurasjonen.
Avsnitt i denne artikkelen:
- Opprett en Delivery Checkout som skal brukes med nShift Ship
- Bestill og skriv ut med nShift Ship
- DeliveryCheckout API
Opprett en Delivery Checkout som skal brukes med nShift Ship
Hvis du er ny bruker av Delivery Checkout, anbefaler vi at du begynner med å lese disse artiklene:
Før du begynner konfigurasjonen, må du sørge for at du har minst én avsender i adresseboken. Se Adressebok – nShift Delivery Help Center
Du må også angi nShift Ship Actor ID og Key i delen Ship details for Sender i nShift Delivery:
- Gå til Maintenance > Senders.
- Søk etter avsenderen din, eller legg til en ny avsender.
- Angi Actor ID og Key i delen Ship details.
Følg deretter trinnene som er beskrevet i denne artikkelen: Opprett en delivery checkout
Se våre andre artikler om
Delivery Checkout-flyt med nShift Ship:
Bestill og skriv ut med nShift Ship
Du kan bestille og skrive ut forsendelser med Ship via API eller filimport.
Via API
For å bestille og skrive ut forsendelser via Shipment Server API bruker du prepare ID som OrderId-referanse for å utføre handlingen SubmitShipment.
Når du utfører SubmitShipment, må du legge til manglende obligatorisk forsendelsesinformasjon, for eksempel pakkeinformasjon.
Les mer om bruk av StoreOrder for å lagre ordrer for import
Filimport
Du kan importere prepare ID og importere denne verdien til References > ShipAdvisor Reference sammen med obligatorisk forsendelsesinformasjon, for eksempel pakkeinformasjon.
Gå til Ship Help her.
DeliveryCheckoutAPI
DeliveryCheckout API er en integrasjonstjeneste for kommunikasjon mellom Delivery Checkout og nettbutikken din. DeliveryCheckout API bruker et REST API-rammeverk for kommunikasjon med JSON som databærer og tilbyr en rekke funksjoner.
Du finner all generell dokumentasjon for DeliveryCheckoutAPI her.
Når det brukes sammen med nShift Ship, finnes det noen spesielle scenarier som vi dekker nedenfor.
Opprett en delvis forsendelse
POST /delivery-checkouts/{deliveryCheckoutId}/shipmentsOppretter en delvis forsendelse basert på leveringsalternativet forbrukeren har valgt i nettbutikken.
Dette endepunktet er obligatorisk.
Bruk alltid den fullstendige Delivery Checkout-ID-en, siden Delivery Checkout-versjonen er inkludert i ID-en.
URI-parametere
| deliveryCheckoutId | string | Delivery Checkout-ID-en som returneres fra GET-forespørselen | Obligatorisk |
| returnShipmentData | boolean | Forsendelsesdata returneres i svaret. | Valgfritt |
Eksempel på body
{
"selectedOptionId": "3e01c458-b4fb-4a15-9468-f9179a516a0c",
"language": "en",
"orderNo": "order number 123",
"prepareId": "test34",
"receiver": {
"name": "Testname",
"address1": "Testaddress 1",
"zipCode": "1080",
"city": "Ixelles",
"country": "BE",
"mobile": "0733000000",
"email": "email2@example.com"
},
"agent": {
"quickId": "19172",
"name": "DISTRIBUTEUR TRIBES BXL CN",
"address1": "Avenue Louise 279",
"address2": null,
"zipCode": "1050",
"city": "Bruxelles",
"state": null,
"country": "BE",
"mapLongitude": 4.36706,
"mapLatitude": 50.82386,
"phone": null,
"email": null
}
}
Eksempel på svar
{
"sourceSystem": "DH",
"serviceId": "DH:7132",
"optionTitle": "PostNord Varubrev 1:a klass (7132)",
"serviceCaption": "PostNord Varubrev 1:a klass (7132)",
"addons": []
}
Se referanseveiledningen for egenskaper for en beskrivelse av egenskapene.
For skjema og testing kan du se https://api.unifaun.com/rs-docs/ og gå til /delivery-checkouts/{deliveryCheckoutId}/shipments POST.
Hent en delvis forsendelse
GET /delivery-checkout-shipments/{prepareId}Henter en delvis forsendelse som tidligere er opprettet.
URI-parametere
| prepareId | string | Identifikasjon av den delvise forsendelsen. | Obligatorisk |
Eksempel på svar
{
"serviceId": "DCTEST",
"serviceTitle": "Delivery Checkout Test Service",
"sourceSystem": "UO",
"orderNo": "order number 123",
"prepareId": "123",
"sender": {
"quickId": "1",
"name": "nShift AB",
"address1": "Skeppsbron 5-6",
"postalCode": "41121",
"city": "GÖTEBORG",
"country": "SE",
"phone": "+46 31 725 35 00",
"email": "email1@example.com"
},
"receiver": {
"name": "nShift AB",
"address1": "Tegnérgatan 34",
"postalCode": "11359",
"city": "STOCKHOLM",
"country": "SE",
"phone": "+46 8 34 35 15",
"email": "email2@example.com"
}
}Se referanseveiledningen for egenskaper for en beskrivelse av egenskapene.
For skjema og testing kan du se https://api.unifaun.com/rs-docs/ og gå til /delivery-checkout-shipments/{prepareId} GET.
Slett en delvis forsendelse
DELETE /delivery-checkout-shipments/{prepareId}Sletter en delvis forsendelse.
Når den delvise forsendelsen er slettet, kan prepare ID brukes på nytt for nye delvise forsendelser.
URI-parametere
| prepareId | string | Identifikasjon av den delvise forsendelsen | Obligatorisk |
Det returneres ingen response body når en delvis forsendelse slettes.
Se referanseveiledningen for egenskaper for en beskrivelse av egenskapene.
For skjema og testing kan du se https://api.unifaun.com/rs-docs/ og gå til /delivery-checkout-shipments/{prepareId} DELETE.
Hent tjenestens kildesystem
GET /delivery-checkout-shipments/{prepareId}/source-systemHenter kildesystemet som tjenesten for den delvise forsendelsen stammer fra.
Nyttig hvis bare prepare ID er kjent, og Delivery Checkout-konfigurasjonen inneholder alternativer med tjenester fra flere kildesystemer.
URI-parametere
| prepareId | string | Identifikasjon av den delvise forsendelsen. | Obligatorisk |
Se referanseveiledningen for egenskaper for en beskrivelse av egenskapene.
For skjema og testing kan du se https://api.unifaun.com/rs-docs/ og gå til /delivery-checkout-shipments/{prepareId}/source-system GET.